summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorWalter Jang <wjang@google.com>2015-06-02 22:02:58 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2015-06-02 22:03:01 +0000
commit31599988150efb64e4e355c5d228a05a0f2aabed (patch)
tree3fcf398a2253dd660cb555b3977af94836fc6b13 /src
parent3c4d041b925bd45da88d20a88f819b8d02ef9aa5 (diff)
parenta35ef54b651d17536169bb0ba0423ca5ef2839b4 (diff)
downloadpackages_apps_Contacts-31599988150efb64e4e355c5d228a05a0f2aabed.tar.gz
packages_apps_Contacts-31599988150efb64e4e355c5d228a05a0f2aabed.tar.bz2
packages_apps_Contacts-31599988150efb64e4e355c5d228a05a0f2aabed.zip
Merge "Don't allow newly writable contact splits" into mnc-dev
Diffstat (limited to 'src')
-rw-r--r--src/com/android/contacts/editor/ContactEditorBaseFragment.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/com/android/contacts/editor/ContactEditorBaseFragment.java b/src/com/android/contacts/editor/ContactEditorBaseFragment.java
index 52076f78f..d0750e020 100644
--- a/src/com/android/contacts/editor/ContactEditorBaseFragment.java
+++ b/src/com/android/contacts/editor/ContactEditorBaseFragment.java
@@ -754,8 +754,9 @@ abstract public class ContactEditorBaseFragment extends Fragment implements
} else if (Intent.ACTION_EDIT.equals(mAction) ||
ContactEditorBaseActivity.ACTION_EDIT.equals(mAction)) {
HelpUtils.prepareHelpMenuItem(mContext, helpMenu, R.string.help_url_people_edit);
- // Split only if more than one raw profile and not a user profile
- splitMenu.setVisible(mState.size() > 1 && !isEditingUserProfile());
+ // Split only if there is more than one raw (non-user profile) contact and doing so
+ // won't result in an empty contact
+ splitMenu.setVisible(mState.size() > 1 && !isEditingUserProfile() && !mHasNewContact);
// Cannot join a user profile
joinMenu.setVisible(!isEditingUserProfile());
deleteMenu.setVisible(!mDisableDeleteMenuOption);